@@ -3,10 +3,10 @@
 #' This function models the functional data using a Gaussian model extracted from
 #' the principal components of the srvfs
 #'
-#' @param warp_data fdawarp object from [time_warping] of aligned data
+#' @param warp_data `fdawarp` object from [time_warping] of aligned data
 #' @param n number of random samples (n = 1)
 #' @param sort_samples sort samples (default = F)
-#' @return Returns a fdawarp object containing \item{fs}{random aligned samples}
+#' @return Returns a `fdawarp` object containing \item{fs}{random aligned samples}
 #' \item{gams}{random warping function samples}
 #' \item{ft}{random function samples}
 #' @keywords pca
@@ -105,7 +105,7 @@ gauss_model <- function(warp_data,n = 1,sort_samples = FALSE){
     warp_data$gams = rgam
     warp_data$ft = ft
     warp_data$qs = q_s[1:(end-1),]
-    warp_data$rsamps=T
+    warp_data$rsamps=TRUE
 
     return(warp_data)
 }
