@@ -1,54 +1,9 @@
-#include <cstring>
-#include <cmath>
-#include <iostream>
-#include <stdio.h>
-#include <Rcpp.h>
 #include "UnitSquareImage.h"
 #include "ImageRegister.h"
 
+#include <Rcpp.h>
+
 using namespace std;
-using namespace Rcpp;
-
-RcppExport SEXP find_grad_2D(SEXP dfdui, SEXP dfdvi, SEXP fi, SEXP ni, SEXP ti, SEXP di){
-    int n = as<int>(ni);
-    int t = as<int>(ti);
-    int d = as<int>(di);
-    NumericVector f(fi);
-    NumericVector dfdu(dfdui);
-    NumericVector dfdv(dfdvi);
-
-    findgrad2D(dfdu.begin(), dfdv.begin(), f.begin(), n, t, d);
-    List ret;
-    ret["dfdu"] = dfdu;
-    ret["dfdv"] = dfdv;
-    return(ret);
-}
-
-RcppExport SEXP check_cross(SEXP fi, SEXP ni, SEXP ti, SEXP Di){
-    int temp;
-    int n = as<int>(ni);
-    int t = as<int>(ti);
-    int D = as<int>(Di);
-    NumericVector f(fi);
-
-    temp = check_crossing(f.begin(), n, t, D);
-
-    return wrap(temp);
-}
-
-RcppExport SEXP find_phistar(SEXP wi, SEXP qi, SEXP bi, SEXP ni, SEXP ti, SEXP di, SEXP Ki){
-    int n = as<int>(ni);
-    int t = as<int>(ti);
-    int d = as<int>(di);
-    int K = as<int>(Ki);
-    NumericVector w(wi);
-    NumericVector q(qi);
-    NumericVector b(bi);
-
-    findphistar(w.begin(), q.begin(), b.begin(), n, t, d, K);
-
-    return(w);
-}
 
 void findgrad(double *dfdu, double *dfdv, const double *f, int n, int t) {
     int i, j, k, N = n*t;
@@ -638,7 +593,7 @@ void jacob_image(double *A, const double *F, int n, int t) {
     int j, k, N = n*t;
     double dfdu[2], dfdv[2], du, dv;
     double c=0.0;
-    
+
     du = 1.0/(n-1);
     dv = 1.0/(t-1);
 
